==> klayout-0.14.tar.gz: klayout-0.14/src/gsiDeclDbShape.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "gsi.h"
#include "dbShape.h"

namespace gsi
{

// ---------------------------------------------------------------
//  db::Shape binding

static int object_type (const db::Shape *s)
{
  return int (s->type ());
}

static int text_font (const db::Shape *s)
{
  return int (s->text_font ());
}

static db::Shape::coord_type path_bgnext (const db::Shape *s)
{
  return s->path_extensions ().first;
}

static db::Shape::coord_type path_endext (const db::Shape *s)
{
  return s->path_extensions ().second;
}

static db::Shape::path_type get_path (const db::Shape *s)
{
  db::Shape::path_type p;
  s->path (p);
  return p;
}

static db::Shape::polygon_type get_polygon (const db::Shape *s)
{
  db::Shape::polygon_type p;
  s->polygon (p);
  return p;
}

static db::Shape::simple_polygon_type get_simple_polygon (const db::Shape *s)
{
  db::Shape::simple_polygon_type p;
  s->simple_polygon (p);
  return p;
}

static db::Shape::box_type get_box (const db::Shape *s)
{
  db::Shape::box_type p;
  s->box (p);
  return p;
}

static db::Shape::edge_type get_edge (const db::Shape *s)
{
  db::Shape::edge_type p;
  s->edge (p);
  return p;
}

static db::Shape::text_type get_text (const db::Shape *s)
{
  db::Shape::text_type p;
  s->text (p);
  return p;
}

static int t_null ()                        { return db::Shape::Null; }
static int t_polygon ()                     { return db::Shape::Polygon; }
static int t_polygonRef ()                  { return db::Shape::PolygonRef; }
static int t_polygonPtrArray ()             { return db::Shape::PolygonPtrArray; }
static int t_polygonPtrArrayMember ()       { return db::Shape::PolygonPtrArrayMember; }
static int t_simplePolygon ()               { return db::Shape::SimplePolygon; }
static int t_simplePolygonRef ()            { return db::Shape::SimplePolygonRef; }
static int t_simplePolygonPtrArray ()       { return db::Shape::SimplePolygonPtrArray; }
static int t_simplePolygonPtrArrayMember () { return db::Shape::SimplePolygonPtrArrayMember; }
static int t_edge ()                        { return db::Shape::Edge; }
static int t_path ()                        { return db::Shape::Path; }
static int t_pathRef ()                     { return db::Shape::PathRef; }
static int t_pathPtrArray ()                { return db::Shape::PathPtrArray; }
static int t_pathPtrArrayMember ()          { return db::Shape::PathPtrArrayMember; }
static int t_box ()                         { return db::Shape::Box; }
static int t_boxArray ()                    { return db::Shape::BoxArray; }
static int t_boxArrayMember ()              { return db::Shape::BoxArrayMember; }
static int t_shortBox ()                    { return db::Shape::ShortBox; }
static int t_shortBoxArray ()               { return db::Shape::ShortBoxArray; }
static int t_shortBoxArrayMember ()         { return db::Shape::ShortBoxArrayMember; }
static int t_text ()                        { return db::Shape::Text; }
static int t_textRef ()                     { return db::Shape::TextRef; }
static int t_textPtrArray ()                { return db::Shape::TextPtrArray; }
static int t_textPtrArrayMember ()          { return db::Shape::TextPtrArrayMember; }
static int t_userObject ()                  { return db::Shape::UserObject; }

template <>
Class<db::Shape> Class<db::Shape>::decl ("Shape", 
  gsi::method ("prop_id", (db::PropertiesRepository::properties_id_type (db::Shape::*) () const) &db::Shape::prop_id,
    "@brief Get the properties Id associated with the shape\n"
  ) +
  gsi::method ("has_prop_id?", &db::Shape::has_prop_id,
    "@brief Check, if the shape is associated with a properties Id\n"
  ) +
  gsi::iterator ("each_point", &db::Shape::begin_point, &db::Shape::end_point,
    "@brief Iterate over all points of the object\n"
    "\n"
    "This method applies to paths.\n"
  ) +
  gsi::iterator ("each_point_hull", &db::Shape::begin_hull, &db::Shape::end_hull,
    "@brief Iterate over the hull contour of the object\n"
    "\n"
    "This method applies to polygons.\n"
  ) +
  gsi::iterator ("each_point_hole", &db::Shape::begin_hole, &db::Shape::end_hole,
    "@brief Iterate over the points of a hole contour\n"
    "@args hole_index\n"
    "\n"
    "This method applies to polygons.\n"
    "Simple polygons deliver an empty sequence.\n"
    "\n"
    "@param hole The hole index (see holes () method)\n"
  ) +
  gsi::method ("holes", &db::Shape::holes,
    "@brief Return the number of holes\n"
    "\n"
    "This method applies to polygons.\n"
    "Simple polygons deliver a zero value.\n"
  ) +
  gsi::iterator ("each_edge", &db::Shape::begin_edge,
    "@brief Iterate over the edges of the object\n"
    "\n"
    "This method applies to polygons and simple polygons.\n"
  ) +
  gsi::method_ext ("type", &object_type, 
    "@brief Return the type of the shape reference\n"
    "\n"
    "The returned values are the t_... constants available through the corresponding class members.\n"
  ) +
  gsi::method ("is_null?", &db::Shape::is_null,
    "@brief Test if the shape proxy is a null object\n"
  ) +
  gsi::method ("is_polygon?", &db::Shape::is_polygon,
    "@brief Test if the shape proxy points to a polygon\n"
  ) +
  gsi::method_ext ("polygon", &get_polygon,
    "@brief Instantiate the polygon object\n"
    "\n"
    "If a polygon is referenced, this object is instantiated\n"
    "by this method. Paths and boxes are converted to polygons.\n"
  ) +
  gsi::method ("is_simple_polygon?", &db::Shape::is_simple_polygon,
    "@brief Test if the shape proxy points to a simple polygon\n"
  ) +
  gsi::method_ext ("simple_polygon", &get_simple_polygon,
    "@brief Instantiate the simple polygon object\n"
    "\n"
    "If a simple polygon is referenced, this object is instantiated\n"
    "by this method. Paths and boxes are converted to polygons.\n"
  ) +
  gsi::method ("is_path?", &db::Shape::is_path,
    "@brief Test if the shape proxy points to a path\n"
  ) +
  gsi::method ("path_width", &db::Shape::path_width,
    "@brief Obtain the path width\n"
    "\n"
    "Applies to paths only.\n"
  ) +
  gsi::method ("round_path?", &db::Shape::round_path,
    "@brief Returns true, if the path has round ends\n"
    "\n"
    "Applies to paths only. \n"
  ) +
  gsi::method_ext ("path_bgnext", &path_bgnext,
    "@brief Obtain the path's \"begin\" extension\n"
    "\n"
    "Applies to paths only. \n"
  ) +
  gsi::method_ext ("path_endext", &path_endext,
    "@brief Obtain the path's \"end\" extension\n"
    "\n"
    "Applies to paths only. \n"
  ) +
  gsi::method_ext ("path", &get_path,
    "@brief Instantiate the path object\n"
    "\n"
    "If a path is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("is_edge?", &db::Shape::is_edge,
    "@brief Test if the shape proxy points to a edge\n"
  ) +
  gsi::method_ext ("edge", &get_edge,
    "@brief Instantiate the edge object\n"
    "\n"
    "If a edge is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("is_text?", &db::Shape::is_text,
    "@brief Test if the shape proxy points to a text\n"
  ) +
  gsi::method_ext ("text", &get_text,
    "@brief Instantiate the text object\n"
    "\n"
    "If a text is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("text_string", &db::Shape::text_string,
    "@brief Obtain the text string\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method ("text_trans", &db::Shape::text_trans,
    "@brief Obtain the text transformation\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method ("text_size", &db::Shape::text_size,
    "@brief Obtain the text size\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method_ext ("text_font", &text_font,
    "@brief Obtain the text's font\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method ("is_box?", &db::Shape::is_box,
    "@brief Test if the shape proxy points to a box\n"
  ) +
  gsi::method_ext ("box", &get_box,
    "@brief Instantiate the box object\n"
    "\n"
    "If a box is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("is_user_object?", &db::Shape::is_user_object,
    "@brief Test if the shape proxy points to a user object\n"
  ) +
  gsi::method ("is_array_member?", &db::Shape::is_array_member,
    "@brief Returns true, if the shape referenced is a member of a shape array\n"
  ) +
  gsi::method ("array_trans", &db::Shape::array_trans,
    "@brief Get the array instance member transformation\n"
    "\n"
    "This attribute is valid only if \\is_array_member? is true.\n"
    "The transformation returned describes the relative transformation of the \n"
    "array member addressed.\n"
  ) +
  gsi::method ("bbox", &db::Shape::bbox,
    "@brief Compute the bounding box of the shape that is referenced\n"
  ) +
  gsi::method ("!=", &db::Shape::operator!=,
    "@brief Inequality \n"
  ) +
  gsi::method ("==", &db::Shape::operator==,
    "@brief Equality \n"
    "\n"
    "Equality of shapes is not specified by the identity of the objects but by the\n"
    "identity of the pointers - both shapes must reference the same object.\n"
  ) +
  gsi::method ("t_null", &t_null) +
  gsi::method ("t_polygon", &t_polygon) +
  gsi::method ("t_polygon_ref", &t_polygonRef) +
  gsi::method ("t_polygon_ptr_array", &t_polygonPtrArray) +
  gsi::method ("t_polygon_ptr_array_member", &t_polygonPtrArrayMember) +
  gsi::method ("t_simple_polygon", &t_simplePolygon) +
  gsi::method ("t_simple_polygon_ref", &t_simplePolygonRef) +
  gsi::method ("t_simple_polygon_ptr_array", &t_simplePolygonPtrArray) +
  gsi::method ("t_simple_polygon_ptr_array_member", &t_simplePolygonPtrArrayMember) +
  gsi::method ("t_edge", &t_edge) +
  gsi::method ("t_path", &t_path) +
  gsi::method ("t_path_ref", &t_pathRef) +
  gsi::method ("t_path_ptr_array", &t_pathPtrArray) +
  gsi::method ("t_path_ptr_array_member", &t_pathPtrArrayMember) +
  gsi::method ("t_box", &t_box) +
  gsi::method ("t_box_array", &t_boxArray) +
  gsi::method ("t_box_array_member", &t_boxArrayMember) +
  gsi::method ("t_short_box", &t_shortBox) +
  gsi::method ("t_short_box_array", &t_shortBoxArray) +
  gsi::method ("t_short_box_array_member", &t_shortBoxArrayMember) +
  gsi::method ("t_text", &t_text) +
  gsi::method ("t_text_ref", &t_textRef) +
  gsi::method ("t_text_ptr_array", &t_textPtrArray) +
  gsi::method ("t_text_ptr_array_member", &t_textPtrArrayMember) +
  gsi::method ("t_user_object", &t_userObject),
  "@brief A shape proxy \n"
  "\n"
  "The shape proxy is basically a pointer to a shape of different kinds \n"
  "No copy of the shape is created: if the shape proxy is copied the copy still\n"
  "points to the original shape. If the original shape is modified or deleted,\n"
  "the shape proxy will also point to a modified or invalid shape.\n"
  "The proxy can be \"null\" which means a invalid reference.\n"
);

}

==> klayout-0.15.tar.gz: klayout-0.15/src/gsiDeclDbShape.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "gsi.h"
#include "dbShape.h"

namespace gsi
{

// ---------------------------------------------------------------
//  db::Shape binding

static int object_type (const db::Shape *s)
{
  return int (s->type ());
}

static int text_font (const db::Shape *s)
{
  return int (s->text_font ());
}

static db::Shape::coord_type path_bgnext (const db::Shape *s)
{
  return s->path_extensions ().first;
}

static db::Shape::coord_type path_endext (const db::Shape *s)
{
  return s->path_extensions ().second;
}

static db::Shape::path_type get_path (const db::Shape *s)
{
  db::Shape::path_type p;
  s->path (p);
  return p;
}

static db::Shape::polygon_type get_polygon (const db::Shape *s)
{
  db::Shape::polygon_type p;
  s->polygon (p);
  return p;
}

static db::Shape::simple_polygon_type get_simple_polygon (const db::Shape *s)
{
  db::Shape::simple_polygon_type p;
  s->simple_polygon (p);
  return p;
}

static db::Shape::box_type get_box (const db::Shape *s)
{
  db::Shape::box_type p;
  s->box (p);
  return p;
}

static db::Shape::edge_type get_edge (const db::Shape *s)
{
  db::Shape::edge_type p;
  s->edge (p);
  return p;
}

static db::Shape::text_type get_text (const db::Shape *s)
{
  db::Shape::text_type p;
  s->text (p);
  return p;
}

static int t_null ()                        { return db::Shape::Null; }
static int t_polygon ()                     { return db::Shape::Polygon; }
static int t_polygonRef ()                  { return db::Shape::PolygonRef; }
static int t_polygonPtrArray ()             { return db::Shape::PolygonPtrArray; }
static int t_polygonPtrArrayMember ()       { return db::Shape::PolygonPtrArrayMember; }
static int t_simplePolygon ()               { return db::Shape::SimplePolygon; }
static int t_simplePolygonRef ()            { return db::Shape::SimplePolygonRef; }
static int t_simplePolygonPtrArray ()       { return db::Shape::SimplePolygonPtrArray; }
static int t_simplePolygonPtrArrayMember () { return db::Shape::SimplePolygonPtrArrayMember; }
static int t_edge ()                        { return db::Shape::Edge; }
static int t_path ()                        { return db::Shape::Path; }
static int t_pathRef ()                     { return db::Shape::PathRef; }
static int t_pathPtrArray ()                { return db::Shape::PathPtrArray; }
static int t_pathPtrArrayMember ()          { return db::Shape::PathPtrArrayMember; }
static int t_box ()                         { return db::Shape::Box; }
static int t_boxArray ()                    { return db::Shape::BoxArray; }
static int t_boxArrayMember ()              { return db::Shape::BoxArrayMember; }
static int t_shortBox ()                    { return db::Shape::ShortBox; }
static int t_shortBoxArray ()               { return db::Shape::ShortBoxArray; }
static int t_shortBoxArrayMember ()         { return db::Shape::ShortBoxArrayMember; }
static int t_text ()                        { return db::Shape::Text; }
static int t_textRef ()                     { return db::Shape::TextRef; }
static int t_textPtrArray ()                { return db::Shape::TextPtrArray; }
static int t_textPtrArrayMember ()          { return db::Shape::TextPtrArrayMember; }
static int t_userObject ()                  { return db::Shape::UserObject; }

template <>
Class<db::Shape> Class<db::Shape>::decl ("Shape", 
  gsi::method ("prop_id", (db::PropertiesRepository::properties_id_type (db::Shape::*) () const) &db::Shape::prop_id,
    "@brief Get the properties Id associated with the shape\n"
  ) +
  gsi::method ("has_prop_id?", &db::Shape::has_prop_id,
    "@brief Check, if the shape is associated with a properties Id\n"
  ) +
  gsi::iterator ("each_point", &db::Shape::begin_point, &db::Shape::end_point,
    "@brief Iterate over all points of the object\n"
    "\n"
    "This method applies to paths.\n"
  ) +
  gsi::iterator ("each_point_hull", &db::Shape::begin_hull, &db::Shape::end_hull,
    "@brief Iterate over the hull contour of the object\n"
    "\n"
    "This method applies to polygons.\n"
  ) +
  gsi::iterator ("each_point_hole", &db::Shape::begin_hole, &db::Shape::end_hole,
    "@brief Iterate over the points of a hole contour\n"
    "@args hole_index\n"
    "\n"
    "This method applies to polygons.\n"
    "Simple polygons deliver an empty sequence.\n"
    "\n"
    "@param hole The hole index (see holes () method)\n"
  ) +
  gsi::method ("holes", &db::Shape::holes,
    "@brief Return the number of holes\n"
    "\n"
    "This method applies to polygons.\n"
    "Simple polygons deliver a zero value.\n"
  ) +
  gsi::iterator ("each_edge", &db::Shape::begin_edge,
    "@brief Iterate over the edges of the object\n"
    "\n"
    "This method applies to polygons and simple polygons.\n"
  ) +
  gsi::method_ext ("type", &object_type, 
    "@brief Return the type of the shape reference\n"
    "\n"
    "The returned values are the t_... constants available through the corresponding class members.\n"
  ) +
  gsi::method ("is_null?", &db::Shape::is_null,
    "@brief Test if the shape proxy is a null object\n"
  ) +
  gsi::method ("is_polygon?", &db::Shape::is_polygon,
    "@brief Test if the shape proxy points to a polygon\n"
  ) +
  gsi::method_ext ("polygon", &get_polygon,
    "@brief Instantiate the polygon object\n"
    "\n"
    "If a polygon is referenced, this object is instantiated\n"
    "by this method. Paths and boxes are converted to polygons.\n"
  ) +
  gsi::method ("is_simple_polygon?", &db::Shape::is_simple_polygon,
    "@brief Test if the shape proxy points to a simple polygon\n"
  ) +
  gsi::method_ext ("simple_polygon", &get_simple_polygon,
    "@brief Instantiate the simple polygon object\n"
    "\n"
    "If a simple polygon is referenced, this object is instantiated\n"
    "by this method. Paths and boxes are converted to polygons.\n"
  ) +
  gsi::method ("is_path?", &db::Shape::is_path,
    "@brief Test if the shape proxy points to a path\n"
  ) +
  gsi::method ("path_width", &db::Shape::path_width,
    "@brief Obtain the path width\n"
    "\n"
    "Applies to paths only.\n"
  ) +
  gsi::method ("round_path?", &db::Shape::round_path,
    "@brief Returns true, if the path has round ends\n"
    "\n"
    "Applies to paths only. \n"
  ) +
  gsi::method_ext ("path_bgnext", &path_bgnext,
    "@brief Obtain the path's \"begin\" extension\n"
    "\n"
    "Applies to paths only. \n"
  ) +
  gsi::method_ext ("path_endext", &path_endext,
    "@brief Obtain the path's \"end\" extension\n"
    "\n"
    "Applies to paths only. \n"
  ) +
  gsi::method_ext ("path", &get_path,
    "@brief Instantiate the path object\n"
    "\n"
    "If a path is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("is_edge?", &db::Shape::is_edge,
    "@brief Test if the shape proxy points to a edge\n"
  ) +
  gsi::method_ext ("edge", &get_edge,
    "@brief Instantiate the edge object\n"
    "\n"
    "If a edge is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("is_text?", &db::Shape::is_text,
    "@brief Test if the shape proxy points to a text\n"
  ) +
  gsi::method_ext ("text", &get_text,
    "@brief Instantiate the text object\n"
    "\n"
    "If a text is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("text_string", &db::Shape::text_string,
    "@brief Obtain the text string\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method ("text_trans", &db::Shape::text_trans,
    "@brief Obtain the text transformation\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method ("text_size", &db::Shape::text_size,
    "@brief Obtain the text size\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method_ext ("text_font", &text_font,
    "@brief Obtain the text's font\n"
    "\n"
    "Applies to texts only. Will throw an exception if not a text.\n"
  ) +
  gsi::method ("is_box?", &db::Shape::is_box,
    "@brief Test if the shape proxy points to a box\n"
  ) +
  gsi::method_ext ("box", &get_box,
    "@brief Instantiate the box object\n"
    "\n"
    "If a box is referenced, this object is instantiated\n"
    "by this method.\n"
  ) +
  gsi::method ("is_user_object?", &db::Shape::is_user_object,
    "@brief Test if the shape proxy points to a user object\n"
  ) +
  gsi::method ("is_array_member?", &db::Shape::is_array_member,
    "@brief Returns true, if the shape referenced is a member of a shape array\n"
  ) +
  gsi::method ("array_trans", &db::Shape::array_trans,
    "@brief Get the array instance member transformation\n"
    "\n"
    "This attribute is valid only if \\is_array_member? is true.\n"
    "The transformation returned describes the relative transformation of the \n"
    "array member addressed.\n"
  ) +
  gsi::method ("bbox", &db::Shape::bbox,
    "@brief Compute the bounding box of the shape that is referenced\n"
  ) +
  gsi::method ("!=", &db::Shape::operator!=,
    "@brief Inequality \n"
  ) +
  gsi::method ("==", &db::Shape::operator==,
    "@brief Equality \n"
    "\n"
    "Equality of shapes is not specified by the identity of the objects but by the\n"
    "identity of the pointers - both shapes must reference the same object.\n"
  ) +
  gsi::method ("t_null", &t_null) +
  gsi::method ("t_polygon", &t_polygon) +
  gsi::method ("t_polygon_ref", &t_polygonRef) +
  gsi::method ("t_polygon_ptr_array", &t_polygonPtrArray) +
  gsi::method ("t_polygon_ptr_array_member", &t_polygonPtrArrayMember) +
  gsi::method ("t_simple_polygon", &t_simplePolygon) +
  gsi::method ("t_simple_polygon_ref", &t_simplePolygonRef) +
  gsi::method ("t_simple_polygon_ptr_array", &t_simplePolygonPtrArray) +
  gsi::method ("t_simple_polygon_ptr_array_member", &t_simplePolygonPtrArrayMember) +
  gsi::method ("t_edge", &t_edge) +
  gsi::method ("t_path", &t_path) +
  gsi::method ("t_path_ref", &t_pathRef) +
  gsi::method ("t_path_ptr_array", &t_pathPtrArray) +
  gsi::method ("t_path_ptr_array_member", &t_pathPtrArrayMember) +
  gsi::method ("t_box", &t_box) +
  gsi::method ("t_box_array", &t_boxArray) +
  gsi::method ("t_box_array_member", &t_boxArrayMember) +
  gsi::method ("t_short_box", &t_shortBox) +
  gsi::method ("t_short_box_array", &t_shortBoxArray) +
  gsi::method ("t_short_box_array_member", &t_shortBoxArrayMember) +
  gsi::method ("t_text", &t_text) +
  gsi::method ("t_text_ref", &t_textRef) +
  gsi::method ("t_text_ptr_array", &t_textPtrArray) +
  gsi::method ("t_text_ptr_array_member", &t_textPtrArrayMember) +
  gsi::method ("t_user_object", &t_userObject),
  "@brief A shape proxy \n"
  "\n"
  "The shape proxy is basically a pointer to a shape of different kinds.\n"
  "No copy of the shape is created: if the shape proxy is copied the copy still\n"
  "points to the original shape. If the original shape is modified or deleted,\n"
  "the shape proxy will also point to a modified or invalid shape.\n"
  "The proxy can be \"null\" which decribes an invalid reference.\n"
);

}
